@@ -37,7 +37,11 @@ pub struct TerminalOptions {
 
     /// Writes the logs to a file inside the config directory.
     #[clap(long)]
-    pub log_file: bool,
+    pub enable_log_file: bool,
+
+    /// Start window with specified title
+    #[clap(long)]
+    pub title: Option<String>,
 }
 
 impl TerminalOptions {
