@@ -82,6 +82,18 @@ pub struct Colors {
         rename = "tabs-active"
     )]
     pub tabs_active: ColorArray,
+    #[serde(
+        deserialize_with = "deserialize_to_arr",
+        default = "defaults::tabs_active_foreground",
+        rename = "tabs-active-foreground"
+    )]
+    pub tabs_active_foreground: ColorArray,
+    #[serde(
+        deserialize_with = "deserialize_to_arr",
+        default = "defaults::tabs_foreground",
+        rename = "tabs-foreground"
+    )]
+    pub tabs_foreground: ColorArray,
     #[serde(default = "defaults::cursor", deserialize_with = "deserialize_to_arr")]
     pub cursor: ColorArray,
     #[serde(
@@ -102,7 +114,7 @@ pub struct Colors {
     pub bar: ColorArray,
     #[serde(
         default = "defaults::tabs_active_highlight",
-        rename = "tabs-active-highligh",
+        rename = "tabs-active-highlight",
         deserialize_with = "deserialize_to_arr"
     )]
     pub tabs_active_highlight: ColorArray,
@@ -228,7 +240,7 @@ pub struct Colors {
         rename = "selection-foreground"
     )]
     pub selection_foreground: ColorArray,
-    #[serde(default = "defaults::cursor", deserialize_with = "deserialize_to_arr")]
+    #[serde(default = "defaults::split", deserialize_with = "deserialize_to_arr")]
     pub split: ColorArray,
     #[serde(
         default = "defaults::search_match_background",
@@ -265,16 +277,18 @@ impl Default for Colors {
             green: defaults::green(),
             red: defaults::red(),
             yellow: defaults::yellow(),
+            bar: defaults::bar(),
+            tabs: defaults::tabs(),
+            tabs_active_highlight: defaults::tabs_active_highlight(),
             tabs_active: defaults::tabs_active(),
+            tabs_active_foreground: defaults::tabs_active_foreground(),
+            tabs_foreground: defaults::tabs_foreground(),
             cursor: defaults::cursor(),
-            split: defaults::cursor(),
+            split: defaults::split(),
             vi_cursor: defaults::vi_cursor(),
             black: defaults::black(),
             cyan: defaults::cyan(),
             magenta: defaults::magenta(),
-            tabs: defaults::tabs(),
-            tabs_active_highlight: defaults::tabs_active_highlight(),
-            bar: defaults::bar(),
             white: defaults::white(),
             dim_black: defaults::dim_black(),
             dim_blue: defaults::dim_blue(),
@@ -465,13 +479,10 @@ impl ColorBuilder {
 
     pub fn from_hex(mut hex: String, conversion_type: Format) -> Result<Self, String> {
         let mut alpha: f64 = 1.0;
-        let _match3or4_hex = "#?[a-f\\d]{3}[a-f\\d]?";
-        let _match6or8_hex = "#?[a-f\\d]{6}([a-f\\d]{2})?";
-        let non_hex_chars = Regex::new(r"(?i)[^#a-f\\0-9]").unwrap();
+        let non_hex_chars = Regex::new(r"(?i)[^#a-f\d]").unwrap();
 
-        // ^#?[a-f\\d]{3}[a-f\\d]?$|^#?[a-f\\d]{6}([a-f\\d]{2})?$ , "i"
-        let valid_hex_size =
-            Regex::new(r"(?i)^#?[a-f\\0-9]{6}([a-f]\\0-9]{2})?$").unwrap();
+        // match valid 6 or 8 hex characters
+        let valid_hex_size = Regex::new(r"(?i)^#?[a-f\d]{6}([a-f\d]{2})?$").unwrap();
 
         if non_hex_chars.is_match(&hex) {
             return Err(String::from("Error: Character is not valid"));
@@ -484,16 +495,14 @@ impl ColorBuilder {
         hex = hex.replace('#', "");
 
         if hex.len() == 8 {
-            // split_at(6, 8)
-            let items = hex.split_at(4);
-            let alpha_from_hex = items.1.to_string().parse::<i32>().unwrap();
-            hex = items.0.to_string();
-            alpha = (alpha_from_hex / 255) as f64;
-            // hex = hex.split_at(1).0.to_string();
+            let (rgb_part, alpha_part) = hex.split_at(6);
+            let alpha_from_hex = i32::from_str_radix(alpha_part, 16).unwrap();
+            hex = rgb_part.to_string();
+            alpha = (alpha_from_hex as f64) / 255.0;
         }
 
         let rgb = decode_hex(&hex).unwrap_or_default();
-        if rgb.is_empty() || rgb.len() > 4 {
+        if rgb.is_empty() || (rgb.len() != 3 && rgb.len() != 4) {
             return Err(String::from("Error: Invalid string, not able to convert"));
         }
 
@@ -724,4 +733,58 @@ mod tests {
             }
         );
     }
+
+    #[test]
+    fn test_conversion_from_gray_hex_with_alpha() {
+        let color_with_alpha =
+            ColorBuilder::from_hex(String::from("#15151580"), Format::SRGB0_255).unwrap();
+        assert_eq!(
+            color_with_alpha,
+            ColorBuilder {
+                red: 21.0,
+                green: 21.0,
+                blue: 21.0,
+                alpha: 128.0 / 255.0
+            }
+        );
+
+        let color_with_alpha_srgb0_1 =
+            ColorBuilder::from_hex(String::from("#15151580"), Format::SRGB0_1).unwrap();
+        assert_eq!(
+            color_with_alpha_srgb0_1,
+            ColorBuilder {
+                red: 21.0 / 255.0,
+                green: 21.0 / 255.0,
+                blue: 21.0 / 255.0,
+                alpha: 128.0 / 255.0
+            }
+        );
+    }
+
+    #[test]
+    fn test_conversion_from_teal_hex_with_alpha() {
+        let color_with_alpha =
+            ColorBuilder::from_hex(String::from("#06a49b99"), Format::SRGB0_255).unwrap();
+        assert_eq!(
+            color_with_alpha,
+            ColorBuilder {
+                red: 6.0,
+                green: 164.0,
+                blue: 155.0,
+                alpha: 153.0 / 255.0
+            }
+        );
+
+        let color_with_alpha_srgb0_1 =
+            ColorBuilder::from_hex(String::from("#06a49b99"), Format::SRGB0_1).unwrap();
+        assert_eq!(
+            color_with_alpha_srgb0_1,
+            ColorBuilder {
+                red: 6.0 / 255.0,
+                green: 164.0 / 255.0,
+                blue: 155.0 / 255.0,
+                alpha: 153.0 / 255.0
+            }
+        );
+    }
 }
