@@ -15,15 +15,6 @@ pub fn default_cursor_interval() -> u64 {
     800
 }
 
-#[inline]
-pub fn default_max_fps() -> u64 {
-    if cfg!(target_os = "macos") {
-        240
-    } else {
-        90
-    }
-}
-
 #[inline]
 pub fn default_padding_y() -> [f32; 2] {
     [0., 0.]
@@ -93,9 +84,20 @@ pub fn default_theme() -> String {
 
 #[inline]
 pub fn default_editor() -> Shell {
-    Shell {
-        program: String::from("vi"),
-        args: vec![],
+    #[cfg(not(target_os = "windows"))]
+    {
+        Shell {
+            program: String::from("vi"),
+            args: vec![],
+        }
+    }
+
+    #[cfg(target_os = "windows")]
+    {
+        Shell {
+            program: String::from("notepad"),
+            args: vec![],
+        }
     }
 }
 
@@ -211,7 +213,7 @@ pub fn default_config_file_content() -> String {
 # shape - Default cursor shape is 'block'
 # Other available options are: 'underline', 'beam' or 'hidden'
 #
-# blinking - Whether the cursor blinks. The default is true
+# blinking - Whether the cursor blinks. The default is false
 #
 # blinking-interval - Cursor update on milliseconds interval
 #
@@ -222,7 +224,8 @@ pub fn default_config_file_content() -> String {
 
 # Editor
 #
-# Default editor is "vi".
+# Default editor on Linux and MacOS is "vi",
+# on Windows it is "notepad".
 #
 # Whenever the key binding `OpenConfigEditor` is triggered it will
 # use the value of the editor along with the rio configuration path.
@@ -279,12 +282,15 @@ pub fn default_config_file_content() -> String {
 #       will be done like enable font ligatures or emoji support.
 #       For more information please check the docs.
 #
+# • filters: A list of paths to RetroArch slang shaders. Might not work with OpenGL.
+#
 # Example:
 # [renderer]
 # performance = "high"
 # backend = "automatic"
 # disable-unfocused-render = false
 # level = 1
+# filters = []
 
 # Keyboard
 #
@@ -305,9 +311,9 @@ pub fn default_config_file_content() -> String {
 # Note: You can set different font families but Rio terminal
 # will always look for regular font bounds whene
 #
-# You can also set family on root to overwrite all fonts
+# You can also set family on root to overwrite all fonts.
 # [fonts]
-#   family = "cascadiamono"
+# family = "cascadiamono"
 #
 # You can also specify extra fonts to load
 # [fonts]
@@ -320,6 +326,10 @@ pub fn default_config_file_content() -> String {
 # Note: Font features do not have support to live reload on configuration,
 # so to reflect your changes, you will need to close and reopen Rio.
 #
+# You can also disable font hinting. Font hinting is enabled by default.
+# [fonts]
+# hinting = false
+#
 # Example:
 # [fonts]
 # size = 18
@@ -446,6 +456,27 @@ pub fn default_config_file_content() -> String {
 #   { key = "home", with = "super | shift", bytes = [27, 91, 53, 126] }
 # ]
 
+# Platform
+#
+# Rio now allows you to have different configurations per OS
+# You can write ovewrite properties like `Shell`, `Navigation`
+# and `Window`.
+#
+# Example:
+# [shell]
+# # default (in this case will be used only on MacOS)
+# program = "/bin/fish"
+# args = ["--login"]
+#
+# [platform]
+# # Microsoft Windows overwrite
+# windows.shell.program = "pwsh"
+# windows.shell.args = ["-l"]
+#
+# # Linux overwrite
+# linux.shell.program = "tmux"
+# linux.shell.args = ["new-session", "-c", "/var/www"]
+
 # Log level
 #
 # This property enables log level filter and file. The default level is "OFF" and the logs are not logged to a file as default.
