@@ -14,10 +14,9 @@ pub enum WindowMode {
     Windowed,
 }
 
-#[derive(Clone, Default, Serialize, Deserialize, Copy, Debug, PartialEq)]
+#[derive(Clone, Serialize, Deserialize, Copy, Debug, PartialEq)]
 pub enum Decorations {
     #[serde(alias = "enabled")]
-    #[default]
     Enabled,
     #[serde(alias = "disabled")]
     Disabled,
@@ -27,6 +26,19 @@ pub enum Decorations {
     Buttonless,
 }
 
+#[allow(clippy::derivable_impls)]
+impl Default for Decorations {
+    fn default() -> Decorations {
+        #[cfg(target_os = "macos")]
+        {
+            Decorations::Transparent
+        }
+
+        #[cfg(not(target_os = "macos"))]
+        Decorations::Enabled
+    }
+}
+
 #[derive(PartialEq, Serialize, Deserialize, Clone, Debug)]
 pub struct Window {
     #[serde(default = "default_window_width")]
@@ -43,6 +55,10 @@ pub struct Window {
     pub background_image: Option<ImageProperties>,
     #[serde(default = "Decorations::default")]
     pub decorations: Decorations,
+    #[serde(default = "bool::default", rename = "macos-use-unified-titlebar")]
+    pub macos_use_unified_titlebar: bool,
+    #[serde(rename = "initial-title", skip_serializing)]
+    pub initial_title: Option<String>,
 }
 
 impl Default for Window {
@@ -55,6 +71,8 @@ impl Default for Window {
             background_image: None,
             decorations: Decorations::default(),
             blur: false,
+            macos_use_unified_titlebar: false,
+            initial_title: None,
         }
     }
 }
