@@ -18,16 +18,12 @@ use row::Row;
 use std::cmp::{max, min};
 use std::ops::{Bound, Deref, Index, IndexMut, Range, RangeBounds};
 use storage::Storage;
-use sugarloaf::layout::SugarloafLayout;
 
 #[derive(Debug, Copy, Clone)]
 pub enum Scroll {
     Delta(i32),
-    #[allow(unused)]
     PageUp,
-    #[allow(unused)]
     PageDown,
-    #[allow(unused)]
     Top,
     Bottom,
 }
@@ -206,34 +202,42 @@ impl<T: GridSquare + Default + PartialEq + Clone> Grid<T> {
                 min(self.display_offset + positions, self.max_scroll_limit);
         }
 
-        // Create scrollback for the new lines.
-        self.increase_scroll_limit(positions);
+        // Only rotate the entire history if the active region starts at the top.
+        if region.start == 0 {
+            // Create scrollback for the new lines.
+            self.increase_scroll_limit(positions);
 
-        // Swap the lines fixed at the top to their target positions after rotation.
-        //
-        // Since we've made sure that the rotation will never rotate away the entire region, we
-        // know that the position of the fixed lines before the rotation must already be
-        // visible.
-        //
-        // We need to start from the bottom, to make sure the fixed lines aren't swapped with each
-        // other.
-        for i in (0..region.start.0).rev().map(Line::from) {
-            self.raw.swap(i, i + positions);
+            // Swap the lines fixed at the top to their target positions after rotation.
+            //
+            // Since we've made sure that the rotation will never rotate away the entire region, we
+            // know that the position of the fixed lines before the rotation must already be
+            // visible.
+            //
+            // We need to start from the bottom, to make sure the fixed lines aren't swapped with
+            // each other.
+            for i in (0..region.start.0).rev().map(Line::from) {
+                self.raw.swap(i, i + positions);
+            }
+
+            // Rotate the entire line buffer upward.
+            self.raw.rotate(-(positions as isize));
+
+            // Swap the fixed lines at the bottom back into position.
+            let screen_lines = self.screen_lines() as i32;
+            for i in (region.end.0..screen_lines).rev().map(Line::from) {
+                self.raw.swap(i, i - positions);
+            }
+        } else {
+            // Rotate lines without moving anything into history.
+            for i in (region.start.0..region.end.0 - positions as i32).map(Line::from) {
+                self.raw.swap(i, i + positions);
+            }
         }
 
-        // Rotate the entire line buffer upward.
-        self.raw.rotate(-(positions as isize));
-
         // Ensure all new lines are fully cleared.
-        let screen_lines = self.screen_lines();
-        for i in ((screen_lines - positions)..screen_lines).map(Line::from) {
+        for i in (region.end.0 - positions as i32..region.end.0).map(Line::from) {
             self.raw[i].reset(&self.cursor.template);
         }
-
-        // Swap the fixed lines at the bottom back into position.
-        for i in (region.end.0..(screen_lines as i32)).rev().map(Line::from) {
-            self.raw.swap(i, i - positions);
-        }
     }
 
     pub fn clear_viewport<D>(&mut self)
@@ -459,10 +463,16 @@ pub trait Dimensions {
     }
 
     /// square height in pixels.
-    fn square_height(&self) -> f32;
+    #[inline]
+    fn square_height(&self) -> f32 {
+        0.0
+    }
 
     /// square width in pixels.
-    fn square_width(&self) -> f32;
+    #[inline]
+    fn square_width(&self) -> f32 {
+        0.0
+    }
 }
 
 impl<G> Dimensions for Grid<G> {
@@ -510,31 +520,6 @@ impl Dimensions for (usize, usize) {
     }
 }
 
-impl Dimensions for SugarloafLayout {
-    #[inline]
-    fn columns(&self) -> usize {
-        self.columns
-    }
-
-    #[inline]
-    fn screen_lines(&self) -> usize {
-        self.lines
-    }
-
-    #[inline]
-    fn total_lines(&self) -> usize {
-        self.screen_lines()
-    }
-
-    fn square_width(&self) -> f32 {
-        self.dimensions.width
-    }
-
-    fn square_height(&self) -> f32 {
-        self.dimensions.height
-    }
-}
-
 #[derive(Debug, PartialEq, Eq)]
 pub struct Indexed<T> {
     pub pos: Pos,
